# 内置 Agent 执行器

默认情况下，AstrBot 内置 Agent 执行器为默认执行器，您不用进行任何配置，即可使用 AstrBot 的强大的内置 Agent 执行器。`✨ 接入模型服务` 中就是在配置 `内置 Agent 执行器` 的 AI 提供商。

![image](https://files.astrbot.app/docs/source/images/astrbot-agent-runner/image.png)

在内置 Agent 执行器下，您可以使用 AstrBot 的 [MCP 服务器](/use/mcp)、[知识库](/use/knowledge-base)、[网页搜索](/use/websearch)、人格功能。

